This function takes a list of ANOVA tables and joins them into a single tibble.
If an element of the ANOVA list is NULL, then an empty column is added.
join_anovas(anova_list, anova_names)
Arguments
anova_list
A list of ANOVA tables.
anova_names
A character vector specifying the names for each ANOVA in the list.