This function is a wrapper foropenxlsx::saveWorkbook(), but can also open the Excel file immediately after saving. File opening is cross-platform compatible (Windows, macOS, and Linux).
save_wb(
wb,
file = here::here("untitled.xlsx"),
overwrite = FALSE,
open_after_save = TRUE,
...
)A Workbook object to write to file
A character string naming an xlsx file
If TRUE, overwrites the previous excel file
If TRUE, opens the excel file after it was created
Other arguments passed toopenxlsx::saveWorkbook()